package com.halomobi.download.receiver;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.net.ConnectivityManager;

import com.halomobi.download.DownLoadManager;
import com.halomobi.download.bean.DownloadItem;
import com.halomobi.network.schedule.ThreadManager;
import com.halomobi.utils.LogUtils;

public class DownloadReceiver extends BroadcastReceiver {

    public static final String ACTION_DOWNLOAD_PAUSE = "com.ssp.download.action.ACTION_DOWNLOAD_PAUSE";
    public static final String ACTION_DOWNLOAD_CONTINUE = "com.ssp.download.action.ACTION_DOWNLOAD_CONTINUE";
    public static final String ACTION_DOWNLOAD_INSTALL = "com.ssp.download.action.ACTION_DOWNLOAD_INSTALL";
    public static final String ACTION_DOWNLOAD_OPEN = "com.ssp.download.action.ACTION_DOWNLOAD_OPEN";
    public static final String ACTION_CANCEL_DOWNLOAD = "com.ssp.download.action.ACTION_CANCEL_DOWNLOAD";
    public static final String DOWNLOAD_URL = "download_url";
    public static final String PACKAGE_NAME = "package_name";
    public static final String NOTIFICATION_ID = "notification_id";
    private static DownloadReceiver mReceiver = new DownloadReceiver();
    private static IntentFilter mPackageIntentFilter;
    private static IntentFilter mDownloadIntentFilter;
    private static IntentFilter mNetWorkChangeIntentFilter;

    public static synchronized void registerReceiver(Context context) {


        try {
            if (mPackageIntentFilter == null) {
                mPackageIntentFilter = new IntentFilter();
                mPackageIntentFilter.addDataScheme("package");
                mPackageIntentFilter.addAction(Intent.ACTION_PACKAGE_ADDED);
                context.registerReceiver(mReceiver, mPackageIntentFilter);
            }
            if (mDownloadIntentFilter == null) {
                mDownloadIntentFilter = new IntentFilter();
                mDownloadIntentFilter.addAction(ACTION_DOWNLOAD_PAUSE);
                mDownloadIntentFilter.addAction(ACTION_DOWNLOAD_CONTINUE);
                mDownloadIntentFilter.addAction(ACTION_DOWNLOAD_INSTALL);
                mDownloadIntentFilter.addAction(ACTION_DOWNLOAD_OPEN);
                mDownloadIntentFilter.addAction(ACTION_CANCEL_DOWNLOAD);
                context.registerReceiver(mReceiver, mDownloadIntentFilter);
            }
            if (mNetWorkChangeIntentFilter == null) {
                mNetWorkChangeIntentFilter = new IntentFilter();
                mNetWorkChangeIntentFilter.addAction(ConnectivityManager.CONNECTIVITY_ACTION);
                context.registerReceiver(mReceiver, mNetWorkChangeIntentFilter);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public static synchronized void unregisterReceiver(Context context) {
        try {
            if (mPackageIntentFilter != null) {
                mPackageIntentFilter = null;
            }
            if (mDownloadIntentFilter != null) {
                mDownloadIntentFilter = null;
            }
            if (mNetWorkChangeIntentFilter != null) {
                mNetWorkChangeIntentFilter = null;
            }
            context.unregisterReceiver(mReceiver);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    @Override
    public void onReceive(final Context context, final Intent intent) {
        if (context == null || intent == null) {
            return;
        }

        ThreadManager.getShortPool().execute(new Runnable() {
            @Override
            public void run() {
                String action = intent.getAction();
                String packageName;
                String downloadUrl = intent.getStringExtra(DOWNLOAD_URL);
                DownloadItem item = DownLoadManager.getInstance(context).getDownloadItem(downloadUrl);

                switch (action) {
                    case Intent.ACTION_PACKAGE_ADDED:
                        packageName = intent.getData().getSchemeSpecificPart();

                        DownLoadManager.getInstance(context).installedApp(packageName);
                        break;
                    case ACTION_DOWNLOAD_PAUSE:
                        DownLoadManager.getInstance(context).pauseDownload(item);
                        break;
                    case ACTION_DOWNLOAD_CONTINUE:
                        DownLoadManager.getInstance(context).download(item);
                        break;
                    case ACTION_DOWNLOAD_INSTALL:
                        DownLoadManager.getInstance(context).installApp(item);
                        break;
                    case ACTION_DOWNLOAD_OPEN:
                        String pakName = intent.getStringExtra(PACKAGE_NAME);
                        int notification_id = intent.getIntExtra(NOTIFICATION_ID, -1);
                        DownLoadManager.getInstance(context).openApp(pakName, notification_id);
                        break;
                    case ACTION_CANCEL_DOWNLOAD:
                        DownLoadManager.getInstance(context).cancelDownload(item);
                        break;
                    case ConnectivityManager.CONNECTIVITY_ACTION:
//                        DownLoadManager.getInstance(context).init(true);
                        break;
                    default:
                        break;
                }
                LogUtils.d("DownloadReceiver Action   :  " + action);
            }
        });

    }


}
